summaryrefslogtreecommitdiff
path: root/configs
diff options
context:
space:
mode:
authorThomas Bächler <thomas@archlinux.org>2012-07-14 16:07:12 +0200
committerGerardo Exequiel Pozzi <vmlinuz386@yahoo.com.ar>2012-07-16 23:08:35 -0300
commitbb84aa78acb98e13b7c9e9268a55591b30ecc499 (patch)
tree45c3e725d97eaa4f19952f0e175df4ca08e3e3d8 /configs
parent6327470e39efce60509f957136764de416164932 (diff)
Adjust for /lib/modules -> /usr/lib/modules move
Although everything should be fine now (due to the /lib -> /usr/lib symlink), adjust everything to the proper path. Edited (Gerardo): Also rename function name and image name to be consisten. Signed-off-by: Pierre Schmitz <pierre@archlinux.de> Signed-off-by: Gerardo Exequiel Pozzi <vmlinuz386@yahoo.com.ar>
Diffstat (limited to 'configs')
-rw-r--r--configs/releng/aitab.core2
-rw-r--r--configs/releng/aitab.netinstall2
-rwxr-xr-xconfigs/releng/build.sh10
3 files changed, 7 insertions, 7 deletions
diff --git a/configs/releng/aitab.core b/configs/releng/aitab.core
index 6d10a75..ffceeda 100644
--- a/configs/releng/aitab.core
+++ b/configs/releng/aitab.core
@@ -1,6 +1,6 @@
# <img> <mnt> <arch> <sfs_comp> <fs_type> <fs_size>
root-image / %ARCH% xz ext4 50%
-lib-modules /lib/modules %ARCH% xz ext4 50%
+usr-lib-modules /usr/lib/modules %ARCH% xz ext4 50%
usr-share /usr/share any xz ext4 50%
repo-core-%ARCH% /repo/core/%ARCH% %ARCH% xz none 0
repo-core-any /repo/core/any any xz none 0
diff --git a/configs/releng/aitab.netinstall b/configs/releng/aitab.netinstall
index 2231154..ede4033 100644
--- a/configs/releng/aitab.netinstall
+++ b/configs/releng/aitab.netinstall
@@ -1,4 +1,4 @@
# <img> <mnt> <arch> <sfs_comp> <fs_type> <fs_size>
root-image / %ARCH% xz ext4 50%
-lib-modules /lib/modules %ARCH% xz ext4 50%
+usr-lib-modules /usr/lib/modules %ARCH% xz ext4 50%
usr-share /usr/share any xz ext4 50%
diff --git a/configs/releng/build.sh b/configs/releng/build.sh
index b18c756..9593de9 100755
--- a/configs/releng/build.sh
+++ b/configs/releng/build.sh
@@ -121,7 +121,7 @@ make_syslinux() {
cp ${_src_syslinux}/memdisk ${_dst_syslinux}
mkdir -p ${_dst_syslinux}/hdt
cat ${work_dir}/root-image/usr/share/hwdata/pci.ids | gzip -9 > ${_dst_syslinux}/hdt/pciids.gz
- cat ${work_dir}/root-image/lib/modules/*-ARCH/modules.alias | gzip -9 > ${_dst_syslinux}/hdt/modalias.gz
+ cat ${work_dir}/root-image/usr/lib/modules/*-ARCH/modules.alias | gzip -9 > ${_dst_syslinux}/hdt/modalias.gz
: > ${work_dir}/build.${FUNCNAME}
fi
}
@@ -157,10 +157,10 @@ make_customize_root_image() {
fi
}
-# Split out /lib/modules from root-image (makes more "dual-iso" friendly)
-make_lib_modules() {
+# Split out /usr/lib/modules from root-image (makes more "dual-iso" friendly)
+make_usr_lib_modules() {
if [[ ! -e ${work_dir}/build.${FUNCNAME} ]]; then
- mv ${work_dir}/root-image/lib/modules ${work_dir}/lib-modules
+ mv ${work_dir}/root-image/usr/lib/modules ${work_dir}/usr-lib-modules
: > ${work_dir}/build.${FUNCNAME}
fi
}
@@ -322,7 +322,7 @@ make_common_single() {
make_syslinux
make_isolinux
make_customize_root_image
- make_lib_modules
+ make_usr_lib_modules
make_usr_share
make_aitab $1
make_prepare $1